<?xml version="1.0"?>
<!-- Licensed Materials - Property of IBM -->
<!-- rendersvg v5.xsl -->
<!-- (c) Copyright IBM Corporation 2007, 2008.  All Rights Reserved. -->
<!-- U.S. Government Users Restricted Rights:  Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp. -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xlink="http://www.w3.org/1999/xlink" version="1.0">	
	<xsl:output method="xml" media-type="image/svg"  omit-xml-declaration="yes"  indent="yes" />	
	<xsl:param name="AssemblyFilePath"/>	
	<xsl:param name="svgFileName">
		<xsl:value-of select="SAReport/SAReportHeader[1]/@OutputFile_Folder"/><xsl:value-of select="SAReport/SALevel[1]/SAItem[1]/SASVGLink/@xlink:href"/>
	</xsl:param>
	<xsl:param name="FontFamily" select="'Arial'"/>	
	<xsl:variable name="Items" select="//SAItem"/>
	<xsl:variable name="ReportName" select="//SAReportHeader[1]/@Name"/>	
	<xsl:variable name="FullReportFile" select="//SAReportHeader[1]/@ReportFile_Name"/>	
	<xsl:variable name="ReportFile" select="substring-before($FullReportFile,'.rpt')"/>	
	<xsl:variable name="Assembly" select="document($AssemblyFilePath)/Assembly"/>	
	<xsl:variable name="DefaultReport" select="$Assembly/StartReports/StartReport[@IsHomePage='True']"/>	
	<xsl:variable name="HomePageOptions"  select="$Assembly/Execution"/>	
	<xsl:template match="/">		
		<xsl:apply-templates select="document($svgFileName)/svg"/>	
	</xsl:template>	
	<xsl:template match="SALevel">		
		<!--For each symbol definition create a hyperlink-->		
		<xsl:for-each select="SAItem">			
			<xsl:if test="@Class='1'">				
				<xsl:apply-templates select="SALevel/SAItem"/>			
			</xsl:if>		
		</xsl:for-each>	
	</xsl:template>	
	<xsl:template match="svg">
		<xsl:apply-templates select="." mode="copy"/>	
	</xsl:template>	
	<xsl:template match="@*|node()" mode="copy">		
		<!-- Copy a node -->		
		<xsl:if test="name(.)!='ellipse2'">		
			<xsl:copy>
       <xsl:apply-templates select="@*" mode="copy"/>
        <xsl:choose>
          <xsl:when test="name(.)='g'">
            <xsl:variable name="DefDDID" select="(@ID|@id)[1]"/>
            <xsl:variable name="ThisEntity" select="$Items[@DDID=$DefDDID]"/>
            <xsl:variable name="ThisEntityDef" select="$ThisEntity/SALevel/SAItem"/>
            <xsl:choose>
              <xsl:when test="$ThisEntityDef">
                <xsl:apply-templates select="." mode="GetLookUp">
                  <xsl:with-param name="ThisEntityDef" select="$ThisEntityDef"/>
                </xsl:apply-templates>
              </xsl:when>
              <xsl:otherwise>
                <xsl:if test="name(.)!='ellipse'">
                  <xsl:apply-templates mode="copy"/>
                </xsl:if>
                <xsl:apply-templates mode="Child" select="."/>
                <xsl:apply-templates mode="LinkedDoc" select="."/>
              </xsl:otherwise>
            </xsl:choose>
          </xsl:when>
          <xsl:when test="name(.)='svg'">
            <xsl:attribute name="onload">initHtmlClean()</xsl:attribute>
            <script type="text/ecmascript" xlink:href="htmlclean.js" />
            <!-- include this stylsheet to allow multiple child diagram popups-->
            <style type="text/css">							
						  <![CDATA[
									.FillWhite{fill:#FFFFFF;}
									.FillPopUpRect{fill:#99CCFF;}
									.FillPopUpRectHyp{fill:rgb(255,200,200);}
									.FillYellow{fill:#FFFF00;}
									.FillLGreen{fill:#99FF99;}
									.DisplayNone{display:none;}
									.Display{display:inline;}
									.MyRect{ fill:rgb(255,255,255); stroke: rgb(0,0,0); stroke-opacity: 1.0; stroke-width: 1;}
									.MyRectHyp{ fill:rgb(255,50,50); stroke: rgb(0,0,200); stroke-opacity: 1.0; stroke-width: 1;}
									.MyFont{ font-family: ]]><xsl:value-of select="$FontFamily"/>
						  <![CDATA[; font-size: 8pt; font-weight: normal; font-style: normal; text-decoration: none; word-spacing: normal; letter-spacing: normal;  stroke: rgb(0,0,0); stroke-width: 0.0;  fill: rgb(0,0,0)}
							]]>
						</style>
						<xsl:apply-templates mode="copy"/>				
					</xsl:when>				
					<xsl:otherwise>
						<xsl:apply-templates mode="copy"/>				
					</xsl:otherwise>			
				</xsl:choose>		
			</xsl:copy>		
		</xsl:if>	
	</xsl:template>	
	<xsl:template match="*" mode="GetLookUp">		
		<xsl:param name="ThisEntityDef"/>		
		<xsl:variable name="ThisEntityDefDDID" select="$ThisEntityDef/@DDID"/>		
		<xsl:variable name="EntityType" select="$ThisEntityDef/@Type"/>		
		<xsl:variable name="EntityClass" select="$ThisEntityDef/@Class"/>		
		<xsl:variable name="ExLookUp" select="$Assembly//Exceptions/LookUp[@ReportFile=$ReportFile and @ReportName=$ReportName]/SAEntity"/>		
		<xsl:variable name="ExLookUpSAEntity" select="$ExLookUp[@SAClass=$EntityClass and @SAType=$EntityType]"/>		
		<xsl:choose>			
			<xsl:when test="$ExLookUpSAEntity">				
				<xsl:apply-templates mode="Hyperlink" select=".">					
					<xsl:with-param name="LookUpSAEntity" select="$ExLookUpSAEntity"/>					
					<xsl:with-param name="DefDDID" select="$ThisEntityDefDDID"/>				
				</xsl:apply-templates>			
			</xsl:when>			
			<xsl:otherwise>				
				<xsl:variable name="DefaultType" select="$Assembly//DefaultType/SAEntity[@SAClass=$EntityClass][@SAType=$EntityType]"/>				
				<xsl:choose>					
					<xsl:when test="$DefaultType">						
						<xsl:apply-templates mode="Hyperlink" select=".">							
							<xsl:with-param name="LookUpSAEntity" select="$DefaultType"/>							
							<xsl:with-param name="DefDDID" select="$ThisEntityDefDDID"/>						
						</xsl:apply-templates>					
					</xsl:when>					
					<xsl:otherwise>						
						<xsl:variable name="DefaultClass" select="$Assembly//DefaultClass/SAEntity[@SAClass=$EntityClass]"/>						
						<xsl:choose>							
							<xsl:when test="$DefaultClass">								
								<xsl:apply-templates mode="Hyperlink" select=".">									
									<xsl:with-param name="LookUpSAEntity" select="$DefaultClass"/>									
									<xsl:with-param name="DefDDID" select="$ThisEntityDefDDID"/>								
								</xsl:apply-templates>							
							</xsl:when>							
							<xsl:otherwise>									
								<xsl:apply-templates mode="copy"/>								
								<xsl:apply-templates mode="Child" select="."/>								
								<xsl:apply-templates mode="LinkedDoc" select="."/>							
							</xsl:otherwise>						
						</xsl:choose>					
					</xsl:otherwise>				
				</xsl:choose>			
			</xsl:otherwise>		
		</xsl:choose>	
	</xsl:template>	
	<xsl:template name="Hyperlink" match="*" mode="Hyperlink">		
		<xsl:param name="LookUpSAEntity"/>		
		<!-- the node in the assembly.xml file that contains the hyperlink-->		
		<xsl:param name="DefDDID"/>		
		<!-- the ddid of the item to be hyperlinked TO -->		
		<xsl:choose>			
			<xsl:when test="$LookUpSAEntity/@ChildReportName !='No Report'">				
				<xsl:variable name="ReportFile" select="$LookUpSAEntity/@ChildReportFile"/>				
				<xsl:variable name="ReportName" select="$LookUpSAEntity/@ChildReportName"/>	
				<xsl:variable name="StyleSheetName" select="$LookUpSAEntity[1]/@StyleSheet"/>
				<xsl:variable name="AClnReportFile"><xsl:value-of select="$ReportFile"/><xsl:text></xsl:text></xsl:variable>
				<xsl:variable name="ClnReportFile" select="$AClnReportFile"/>
				<xsl:variable name="AClnReportName" select="$ReportName"/>
				<xsl:variable name="ClnReportName" select="$AClnReportName"/>
				<xsl:choose>					
					<xsl:when test="($HomePageOptions/HomePageOptions/@HomePageUseReportPage='True') and (($DefDDID=$DefaultReport/SAItemToReport/@DDID) and ($ReportFile=$DefaultReport/@ReportFile) and ($ReportName=$DefaultReport/@ReportName))">						
						<xsl:element name="a">							
							<xsl:attribute name="xlink:href" >								
								<xsl:choose>									
									<xsl:when test="$HomePageOptions/@CreateBrowserTree='True'">										
										<xsl:text>Main.htm</xsl:text>									
									</xsl:when>									
									<xsl:otherwise>										
										<xsl:text>Default.htm</xsl:text>									
									</xsl:otherwise>								
								</xsl:choose>							
							</xsl:attribute>							
							<xsl:apply-templates mode="copy"/>						
						</xsl:element>					
					</xsl:when>					
					<xsl:otherwise>						
						<xsl:element name="a">							
							<xsl:attribute name="xlink:href" >	
								<xsl:text>getpage.aspx?ReportFile=</xsl:text>
								<xsl:value-of select="$ClnReportFile"/>
								<xsl:text disable-output-escaping="yes">&amp;ReportName=</xsl:text>
								<xsl:value-of select="$ClnReportName"/>
								<xsl:text disable-output-escaping="yes">&amp;DDID=</xsl:text>
								<xsl:value-of select="$DefDDID"/>
								<xsl:text disable-output-escaping="yes">&amp;StyleSheet=</xsl:text>
								<xsl:value-of select="$StyleSheetName"/>
							</xsl:attribute>
							<xsl:attribute name="target" >
								<xsl:text>_blank</xsl:text>
							</xsl:attribute>
							<xsl:apply-templates mode="copy"/>						
						</xsl:element>					
					</xsl:otherwise>				
				</xsl:choose>			
			</xsl:when>			
			<xsl:otherwise>				
				<xsl:apply-templates mode="copy"/>			
			</xsl:otherwise>		
		</xsl:choose>		
		<xsl:apply-templates mode="Child" select="."/>		
		<xsl:apply-templates mode="LinkedDoc" select="."/>
	</xsl:template>	
	<xsl:template match="g" mode="LinkedDoc">		
		<xsl:variable name="ThisG" select="."/>		
		<xsl:variable name="DefDDID" select="(@ID|@id)[1]"/>		
		<xsl:variable name="ThisEntity" select="$Items[@DDID=$DefDDID]"/>		
		<xsl:variable name="ThisEntityDef" select="$ThisEntity/SALevel/SAItem"/>		
		<xsl:apply-templates mode="HyperlinkSquare" select="$ThisG">			
			<xsl:with-param name="Def" select="$ThisEntityDef"/>		
		</xsl:apply-templates>	
	</xsl:template>	
	<xsl:template match="g" mode="HyperlinkSquare">		
		<xsl:param name="Def"/>		
		<xsl:variable name="Hyperlinks" select="$Def/SALevel/SAItem[@TypeName='Hyperlink']|$Def/SALinkedDoc/SAItem"/>		
		<xsl:variable name="ListOfHyperlinks" select="$Hyperlinks"/>		
		<xsl:if test="count($ListOfHyperlinks) &gt; 0">			
			<xsl:variable name="ThisG" select="."/>			
			<!--the child dgm indicator symbol-->			
			<g id="Hchild{(($ThisG/@id)|($ThisG/@ID))[1]}">				
				<xsl:apply-templates mode="DrawPopupFromRectangleHyp" select="$ThisG/rect"/>				
				<xsl:element name="g">					
					<!--the containet for the child diagram names-->					
					<xsl:attribute name="id">						
						<xsl:text>HPopup</xsl:text>						
						<xsl:value-of select="(($ThisG/@id)|($ThisG/@ID))[1]"/>					
					</xsl:attribute>					
					<xsl:attribute name="class">DisplayNone</xsl:attribute>					
					<xsl:apply-templates mode="DrawPopupToRectangleHyp" select="$ThisG/rect[1]">						
						<xsl:with-param name="xxchildrenx" select="$Def"/>					
						<xsl:with-param name="LinkCount" select="count($ListOfHyperlinks)"/>					
					</xsl:apply-templates>
					<xsl:for-each select="$ListOfHyperlinks">						
						<xsl:variable name="ChildNumber" select="position()"/>						
						<xsl:apply-templates mode="SquareHyperlinkHyp" select="$ThisG/rect[1]">							
							<xsl:with-param name="Hyperlink" select="SAProperty[@SAPrpName='Description']/@SAPrpValue"/>							
							<xsl:with-param name="ItemTitle" select="@Name"/>							
							<xsl:with-param name="VerticalPosition" select="$ChildNumber"/>						
						</xsl:apply-templates>					
					</xsl:for-each>				
				</xsl:element>				
				<set id="HShowPopup{(($ThisG/@id)|($ThisG/@ID))[1]}" xlink:href="#HPopup{(($ThisG/@id)|($ThisG/@ID))[1]}" attributeName="display" from="none" to="inline" begin="Hchild{(($ThisG/@id)|($ThisG/@ID))[1]}.click" dur="3s"/>			
			</g>		
		</xsl:if>	
	</xsl:template>	
	<xsl:template name="SquareHyperlinkHyp" match="rect" mode="SquareHyperlinkHyp">		
		<xsl:param name="Hyperlink"/>		
		<!-- the ddid of the item to be hyperlinked TO -->		
		<xsl:param name="ItemTitle"/>		
		<!-- the position of the text in the rectangle-->		
		<xsl:param name="VerticalPosition"/>
		<xsl:variable name="NameExtarnal" select="contains($Hyperlink,'http')"/>
		<xsl:variable name="NameInternal" select="contains($Hyperlink,':\')"/>
		<xsl:variable name="NameUTC" select="contains($Hyperlink,'\\')"/>
		<xsl:variable name="FName" select="$Hyperlink"/>
		<xsl:variable name="XPos" select="@x + 5"/>		
		<xsl:variable name="YPos" select="@y + @height - (@height div 10) + (($VerticalPosition - 1) * 13) + 12"/>
        <xsl:element name="a">
            <xsl:attribute name="xlink:href">
			    <xsl:choose>
						<xsl:when test="$NameExtarnal or $NameUTC or $NameInternal">
							<xsl:value-of select="$Hyperlink"/>
						</xsl:when>
						<xsl:otherwise>
							 <xsl:text>GetFile.aspx?filename=</xsl:text>
							 <xsl:value-of select="$ItemTitle"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			    <xsl:attribute name="target">
					<xsl:if test="$NameExtarnal or $NameUTC">
						<xsl:text>_blank</xsl:text>
					</xsl:if>
			    </xsl:attribute>
			<text x="{$XPos}" y="{$YPos}" class="MyFont">-
			 <xsl:choose>
				 <xsl:when test="$NameInternal or $NameUTC">
					 <xsl:value-of select="$Hyperlink"/>
				</xsl:when>
				 <xsl:otherwise>
					 <xsl:value-of select="$ItemTitle"/>
				 </xsl:otherwise>
			 </xsl:choose>
		</text>
		</xsl:element>
	 </xsl:template>	
	<xsl:template match ="rect" mode="DrawPopupToRectangleHyp">		
		<xsl:param name="xxchildrenx"/>		
		<xsl:param name="LinkCount"/>		
		<!-- this rectangle must be of height relative to the number of items within it-->
		<xsl:variable name="test" select="$xxchildrenx"/>		
		<xsl:variable name="noofchildren" select="$LinkCount"/>		
		<xsl:variable name="XPos" select="@x"/>		
		<xsl:variable name="XSize" select="@width + 140"/>		
		<xsl:variable name="YSize" select="($noofchildren * 13) + 3"/>		
		<xsl:variable name="YPos" select="@y + @height - (@height div 10)"/>		
		<rect x="{$XPos}" y="{$YPos}" width="{$XSize}" height="{$YSize}" class="FillPopUpRectHyp"/>	
	</xsl:template>	
	<xsl:template match ="rect" mode="DrawPopupFromRectangleHyp">		
		<xsl:variable name="XPos" select="@x  - 20"/>		
		<xsl:variable name="XSize" select="20"/>		
		<xsl:variable name="YSize" select="16"/>		
		<xsl:variable name="YPos" select="@y + @height - $YSize"/>		
		<rect x="{$XPos}" y="{$YPos -1}" width="{$XSize}" height="{$YSize + 1}" class="MyRectHyp"/>		
		<text x="{$XPos + 1.5}" y="{$YPos + (@height div 10)}" class="MyFont">H</text>	
	</xsl:template>	
	<xsl:template match="g" mode="Child">		
		<xsl:variable name="ThisG" select="."/>		
		<xsl:variable name="DefDDID" select="(@ID|@id)[1]"/>		
		<xsl:variable name="ThisEntity" select="$Items[@DDID=$DefDDID]"/>		
		<xsl:variable name="ThisEntityChildLink" select="$ThisEntity/SALink[@xlink:title='Child Diagrams']/@xlink:href"/>		
		<xsl:if test="$ThisEntityChildLink">			
			<xsl:variable name="ThisEntityChildLinkFile" select="document($ThisEntity/SALink[@xlink:title='Child Diagrams']/@xlink:href)"/>			
			<xsl:variable name="ThisEntityChildDiagrams" select="$ThisEntityChildLinkFile/SAReport/SALevel/SAItem/SALevel"/>			
			<xsl:if test="$ThisEntityChildDiagrams">				
				<!-- do we have child diagrams?-->				
				<xsl:apply-templates mode="DoChildSquare" select="$ThisG">					
					<xsl:with-param name="ChildDgms" select="$ThisEntityChildDiagrams"/>				
				</xsl:apply-templates>			
			</xsl:if>		
		</xsl:if>	
	</xsl:template>	
	<xsl:template match="g" mode="DoChildSquare">		
		<xsl:param name="ChildDgms"/>		
		<xsl:variable name="ListOfChildren" select="$ChildDgms/SAItem"/>		
		<xsl:if test="count($ListOfChildren) &gt; 0">			
			<xsl:variable name="ThisG" select="."/>			
			<!--the child dgm indicator symbol-->			
			<g id="child{(($ThisG/@id)|($ThisG/@ID))[1]}">				
				<xsl:apply-templates mode="DrawPopupFromRectangleDetectType" select="$ThisG"/>				
				<xsl:element name="g">					
					<!--the containet for the child diagram names-->					
					<xsl:attribute name="id">						
						<xsl:text>Popup</xsl:text>						
						<xsl:value-of select="(($ThisG/@id)|($ThisG/@ID))[1]"/>					
					</xsl:attribute>					
					<xsl:attribute name="class">DisplayNone</xsl:attribute>					
					<xsl:apply-templates mode="DrawPopupToRectangleDetectType" select="$ThisG">						
						<xsl:with-param name="xxchildrenx" select="$ChildDgms"/>					
					</xsl:apply-templates>					
					<xsl:for-each select="$ListOfChildren">						
						<xsl:variable name="ChildNumber" select="position()"/>						
						<xsl:variable name="ThisEntityDefDDID" select="@DDID"/>						
						<xsl:variable name="EntityType" select="@Type"/>						
						<xsl:variable name="EntityClass" select="@Class"/>						
						<xsl:variable name="ExLookUp" select="$Assembly//Exceptions/LookUp[@ReportFile=$ReportFile and @ReportName=$ReportName]/SAEntity"/>						
						<xsl:variable name="ExLookUpSAEntity" select="$ExLookUp[@SAClass=$EntityClass and @SAType=$EntityType]"/>						
						<xsl:choose>							
							<xsl:when test="$ExLookUpSAEntity">								
								<xsl:apply-templates mode="DoSquareHyperlinkDetectType" select="$ThisG">									
									<xsl:with-param name="LookUpSAEntity" select="$ExLookUpSAEntity"/>									
									<xsl:with-param name="DefDDID" select="$ThisEntityDefDDID"/>									
									<xsl:with-param name="ItemTitle" select="@Name"/>									
									<xsl:with-param name="VerticalPosition" select="$ChildNumber"/>								
								</xsl:apply-templates>							
							</xsl:when>							
							<xsl:otherwise>								
								<xsl:variable name="DefaultType" select="$Assembly//DefaultType/SAEntity[@SAClass=$EntityClass][@SAType=$EntityType]"/>								
								<xsl:choose>									
									<xsl:when test="$DefaultType">										
										<xsl:apply-templates mode="DoSquareHyperlinkDetectType" select="$ThisG">											
											<xsl:with-param name="LookUpSAEntity" select="$DefaultType"/>											
											<xsl:with-param name="DefDDID" select="$ThisEntityDefDDID"/>											
											<xsl:with-param name="ItemTitle" select="@Name"/>											
											<xsl:with-param name="VerticalPosition" select="$ChildNumber"/>										
										</xsl:apply-templates>									
									</xsl:when>									
									<xsl:otherwise>										
										<xsl:variable name="DefaultClass" select="$Assembly//DefaultClass/SAEntity[@SAClass=$EntityClass]"/>										
										<xsl:choose>											
											<xsl:when test="$DefaultClass">												
												<xsl:apply-templates mode="DoSquareHyperlinkDetectType" select="$ThisG">													
													<xsl:with-param name="LookUpSAEntity" select="$DefaultClass"/>													
													<xsl:with-param name="DefDDID" select="$ThisEntityDefDDID"/>													
													<xsl:with-param name="ItemTitle" select="@Name"/>													
													<xsl:with-param name="VerticalPosition" select="$ChildNumber"/>												
												</xsl:apply-templates>											
											</xsl:when>											
											<xsl:otherwise>											</xsl:otherwise>										
										</xsl:choose>					</xsl:otherwise>								
								</xsl:choose>			</xsl:otherwise>						
						</xsl:choose>					
					</xsl:for-each>				
				</xsl:element>				
				<set id="ShowPopup{(($ThisG/@id)|($ThisG/@ID))[1]}" xlink:href="#Popup{(($ThisG/@id)|($ThisG/@ID))[1]}" attributeName="display" from="none" to="inline" begin="child{(($ThisG/@id)|($ThisG/@ID))[1]}.click" dur="3s"/>			
			</g>		
		</xsl:if>	
	</xsl:template>	
	<xsl:template name="DoSquareHyperlinkDetectType" match="g" mode="DoSquareHyperlinkDetectType">		
		<xsl:param name="LookUpSAEntity"/>		
		<!-- the node in the assembly.xml file that contains the hyperlink-->		
		<xsl:param name="DefDDID"/>		
		<!-- the ddid of the item to be hyperlinked TO -->		
		<xsl:param name="ItemTitle"/>		
		<!-- the position of the text in the rectangle-->		
		<xsl:param name="VerticalPosition"/>		
		<xsl:choose>			
			<xsl:when test="rect[1]">				
				<xsl:apply-templates mode="DoSquareHyperlinkFromRect" select="rect[1]">					
					<xsl:with-param name="LookUpSAEntity" select="$LookUpSAEntity"/>					
					<xsl:with-param name="DefDDID" select="$DefDDID"/>					
					<xsl:with-param name="ItemTitle" select="$ItemTitle"/>					
					<xsl:with-param name="VerticalPosition" select="$VerticalPosition"/>				
				</xsl:apply-templates>			
			</xsl:when>			
			<xsl:when test="ellipse[1]">				
				<xsl:apply-templates mode="DoSquareHyperlinkFromEllipse" select="ellipse[1]">					
					<xsl:with-param name="LookUpSAEntity" select="$LookUpSAEntity"/>					
					<xsl:with-param name="DefDDID" select="$DefDDID"/>					
					<xsl:with-param name="ItemTitle" select="$ItemTitle"/>					
					<xsl:with-param name="VerticalPosition" select="$VerticalPosition"/>				
				</xsl:apply-templates>			
			</xsl:when>		
		</xsl:choose>	
	</xsl:template>	
	<xsl:template name="DoSquareHyperlinkFromEllipse" match="ellipse" mode="DoSquareHyperlinkFromEllipse">		
		<xsl:param name="LookUpSAEntity"/>		
		<!-- the node in the assembly.xml file that contains the hyperlink-->		
		<xsl:param name="DefDDID"/>		
		<!-- the ddid of the item to be hyperlinked TO -->		
		<xsl:param name="ItemTitle"/>		
		<!-- the position of the text in the rectangle-->		
		<xsl:param name="VerticalPosition"/>		
		<xsl:variable name="XPosEllipse" select="@cx + 5"/>		
		<xsl:variable name="YPosEllipse" select="@cy + @ry - (@ry div 10) + (($VerticalPosition - 1) * 13) + 12"/>		
		<xsl:apply-templates mode="SquareHyperlink" select=".">			
			<xsl:with-param name="LookUpSAEntity" select="$LookUpSAEntity"/>			
			<xsl:with-param name="DefDDID" select="$DefDDID"/>			
			<xsl:with-param name="ItemTitle" select="$ItemTitle"/>			
			<xsl:with-param name="VerticalPosition" select="$VerticalPosition"/>			
			<xsl:with-param name="XPos" select="$XPosEllipse"/>			
			<xsl:with-param name="YPos" select="$YPosEllipse"/>		
		</xsl:apply-templates>	
	</xsl:template>	
	<xsl:template name="DoSquareHyperlinkFromRect" match="rect" mode="DoSquareHyperlinkFromRect">		
		<xsl:param name="LookUpSAEntity"/>		
		<!-- the node in the assembly.xml file that contains the hyperlink-->		
		<xsl:param name="DefDDID"/>		
		<!-- the ddid of the item to be hyperlinked TO -->		
		<xsl:param name="ItemTitle"/>		
		<!-- the position of the text in the rectangle-->		
		<xsl:param name="VerticalPosition"/>		
		<xsl:variable name="XPos" select="@x + 5"/>		
		<xsl:variable name="YPos" select="@y + @height - (@height div 10) + (($VerticalPosition - 1) * 13) + 12"/>		
		<xsl:apply-templates mode="SquareHyperlink" select=".">			
			<xsl:with-param name="LookUpSAEntity" select="$LookUpSAEntity"/>			
			<xsl:with-param name="DefDDID" select="$DefDDID"/>			
			<xsl:with-param name="ItemTitle" select="$ItemTitle"/>			
			<xsl:with-param name="VerticalPosition" select="$VerticalPosition"/>			
			<xsl:with-param name="XPos" select="$XPos"/>			
			<xsl:with-param name="YPos" select="$YPos"/>		
		</xsl:apply-templates>	
	</xsl:template>	
	<xsl:template name="SquareHyperlink" match="*" mode="SquareHyperlink">		
		<xsl:param name="LookUpSAEntity"/>		
		<!-- the node in the assembly.xml file that contains the hyperlink-->		
		<xsl:param name="DefDDID"/>		
		<!-- the ddid of the item to be hyperlinked TO -->		
		<xsl:param name="ItemTitle"/>		
		<!-- the position of the text in the rectangle-->		
		<xsl:param name="VerticalPosition"/>		
		<xsl:param name="XPos"/>		
		<xsl:param name="YPos"/>		
		<xsl:choose>			
			<xsl:when test="$LookUpSAEntity/@ChildReportName !='No Report'">				
				<xsl:variable name="ReportFile" select="$LookUpSAEntity/@ChildReportFile"/>				
				<xsl:variable name="ReportName" select="$LookUpSAEntity/@ChildReportName"/>				
				<xsl:variable name="AClnReportFile" select="translate($ReportFile,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz')"/>				
				<xsl:variable name="ClnReportFile" select="translate($AClnReportFile,'\/:*?&quot;&lt;&gt;| ','')"/>				
				<xsl:variable name="AClnReportName" select="translate($ReportName,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz')"/>				
				<xsl:variable name="ClnReportName" select="translate($AClnReportName,'\/:*?&quot;&lt;&gt;| ','')"/>				
				<xsl:choose>					
					<xsl:when test="($HomePageOptions/HomePageOptions/@HomePageUseReportPage='True') and (($DefDDID=$DefaultReport/SAItemToReport/@DDID) and ($ReportFile=$DefaultReport/@ReportFile) and ($ReportName=$DefaultReport/@ReportName))">						
						<xsl:element name="a">							
							<xsl:attribute name="xlink:href" >								
								<xsl:choose>									
									<xsl:when test="$HomePageOptions/@CreateBrowserTree='True'">										
										<xsl:text>Main.htm</xsl:text>									
									</xsl:when>									
									<xsl:otherwise>										
										<xsl:text>Default.htm</xsl:text>									
									</xsl:otherwise>								
								</xsl:choose>							
							</xsl:attribute>							
							<text x="{$XPos}" y="{$YPos}" class="MyFont">								
								<xsl:value-of select="$ItemTitle"/>							
							</text>						
						</xsl:element>					
					</xsl:when>					
					<xsl:otherwise>						
						<xsl:element name="a">							
							<xsl:attribute name = "target">
							<xsl:text>_blank</xsl:text>
							</xsl:attribute>
							<xsl:attribute name="xlink:href" >								
								<xsl:text>getpage.aspx?ddid=</xsl:text>								
								<xsl:value-of select="$DefDDID"/>								
							</xsl:attribute>							
							<text x="{$XPos}" y="{$YPos}" class="MyFont">								
								<xsl:text>- </xsl:text>								
								<xsl:value-of select="$ItemTitle"/>							
							</text>						
						</xsl:element>					
					</xsl:otherwise>				
				</xsl:choose>			
			</xsl:when>			
			<xsl:otherwise>				
				<text x="{$XPos}" y="{$YPos}" class="MyFont">					
					<xsl:value-of select="$ItemTitle"/>				
				</text>			
			</xsl:otherwise>		
		</xsl:choose>	
	</xsl:template>	
	<xsl:template match ="g" mode="DrawPopupFromRectangleDetectType">
		<xsl:choose>			
			<xsl:when test="rect[1]">				
				<xsl:apply-templates mode="DrawPopupFromRectangleRect" select="rect[1]"/>			
			</xsl:when>			
			<xsl:when test="ellipse[1]">				
				<xsl:apply-templates mode="DrawPopupFromRectangleEllipse" select="ellipse[1]"/>			
			</xsl:when>		
		</xsl:choose>	
	</xsl:template>	
	<xsl:template match ="g" mode="DrawPopupToRectangleDetectType">		
		<xsl:param name="xxchildrenx"/>		
		<xsl:choose>			
			<xsl:when test="rect[1]">				
				<xsl:apply-templates mode="DrawPopupToRectangleRect" select="rect[1]">					
					<xsl:with-param name="xxchildrenx" select="$xxchildrenx"/>				
				</xsl:apply-templates>			
			</xsl:when>			
			<xsl:when test="ellipse[1]">				
				<xsl:apply-templates mode="DrawPopupToRectangleEllipse" select="ellipse[1]">					
					<xsl:with-param name="xxchildrenx" select="$xxchildrenx"/>				
				</xsl:apply-templates>			
			</xsl:when>		
		</xsl:choose>	
	</xsl:template>	
	<xsl:template match ="rect" mode="DrawPopupToRectangleRect">		
		<xsl:param name="xxchildrenx"/>		
		<!-- this rectangle must be of height relative to the number of items within it-->		
		<xsl:variable name="test" select="$xxchildrenx"/>		
		<xsl:variable name="noofchildren" select="count($test/SAItem)"/>		
		<xsl:variable name="XPos" select="@x"/>		
		<xsl:variable name="XSize" select="@width + 60"/>		
		<xsl:variable name="YSize" select="($noofchildren * 13) + 3"/>		
		<xsl:variable name="YPos" select="@y + @height - (@height div 10)"/>		
		<rect x="{$XPos}" y="{$YPos}" width="{$XSize}" height="{$YSize}" class="FillPopUpRect"/>	
	</xsl:template>	
	<xsl:template match ="ellipse" mode="DrawPopupToRectangleEllipse">		
		<xsl:param name="xxchildrenx"/>		
		<!-- this rectangle must be of height relative to the number of items within it-->		
		<xsl:variable name="test" select="$xxchildrenx"/>		
		<xsl:variable name="noofchildren" select="count($test/SAItem)"/>		
		<xsl:variable name="XPos" select="@cx"/>		
		<xsl:variable name="XSize" select="250"/>		
		<xsl:variable name="YSize" select="($noofchildren * 13) + 3"/>		
		<xsl:variable name="YPos" select="@cy + @ry - (@ry div 10)"/>		
		<rect x="{$XPos}" y="{$YPos}" width="{$XSize}" height="{$YSize}" class="FillPopUpRect"/>	
	</xsl:template>	
	<xsl:template match ="ellipse" mode="DrawPopupFromRectangleEllipse">		
		<xsl:variable name="XPos" select="@cx  - 10 + (@rx div 2)"/>		
		<xsl:variable name="XSize" select="20"/>		
		<xsl:variable name="YSize" select="16"/>		
		<xsl:variable name="YPos" select="@cy + @ry - $YSize"/>		
		<rect x="{$XPos}" y="{$YPos -1}" width="{$XSize}" height="{$YSize + 1}" class="MyRect"/>		
		<text x="{$XPos + 1.5}" y="{$YPos + 10}" class="MyFont">+</text>	
	</xsl:template>	
	<xsl:template match ="rect" mode="DrawPopupFromRectangleRect">		
		<xsl:variable name="XPos" select="@x  - 7 + (@width div 2)"/>		
		<xsl:variable name="XSize" select="20"/>		
		<xsl:variable name="YSize" select="24"/>		
		<xsl:variable name="YPos" select="@y + @height - $YSize"/>		
		<rect x="{$XPos}" y="{$YPos -1}" width="{$XSize - 3}" height="{$YSize -6}" class="MyRect"/>		
		<text x="{$XPos + 3.5}" y="{$YPos +  13}" class="MyFont">+</text>	
	</xsl:template>	
	<xsl:template match="g" mode="DoEllipse">		
		<xsl:param name="ThisEntityDef"/>		
		<xsl:variable name="ThisEntityDefDDID" select="$ThisEntityDef/@DDID"/>		
		<xsl:variable name="EntityType" select="$ThisEntityDef/@Type"/>		
		<xsl:variable name="EntityClass" select="$ThisEntityDef/@Class"/>		
		<xsl:variable name="ExLookUp" select="$Assembly//Exceptions/LookUp[@ReportFile=$ReportFile and @ReportName=$ReportName]/SAEntity"/>		
		<xsl:variable name="ExLookUpSAEntity" select="$ExLookUp[@SAClass=$EntityClass and @SAType=$EntityType]"/>		
		<xsl:choose>			
			<xsl:when test="$ExLookUpSAEntity">				
				<xsl:apply-templates mode="EllipseHyperlink" select=".">					
					<xsl:with-param name="LookUpSAEntity" select="$ExLookUpSAEntity"/>					
					<xsl:with-param name="DefDDID" select="$ThisEntityDefDDID"/>				
				</xsl:apply-templates>			
			</xsl:when>			
			<xsl:otherwise>				
				<xsl:variable name="DefaultType" select="$Assembly//DefaultType/SAEntity[@SAClass=$EntityClass][@SAType=$EntityType]"/>				
				<xsl:choose>					
					<xsl:when test="$DefaultType">						
						<xsl:apply-templates mode="EllipseHyperlink" select=".">							
							<xsl:with-param name="LookUpSAEntity" select="$DefaultType"/>							
							<xsl:with-param name="DefDDID" select="$ThisEntityDefDDID"/>						
						</xsl:apply-templates>					
					</xsl:when>					
					<xsl:otherwise>						
						<xsl:variable name="DefaultClass" select="$Assembly//DefaultClass/SAEntity[@SAClass=$EntityClass]"/>						
						<xsl:choose>							
							<xsl:when test="$DefaultClass">								
								<xsl:apply-templates mode="EllipseHyperlink" select=".">									
									<xsl:with-param name="LookUpSAEntity" select="$DefaultClass"/>									
									<xsl:with-param name="DefDDID" select="$ThisEntityDefDDID"/>								
								</xsl:apply-templates>							
							</xsl:when>							
							<xsl:otherwise>								
								<xsl:apply-templates mode="SimpleCopy" select="ellipse"/>							
							</xsl:otherwise>						
						</xsl:choose>					
					</xsl:otherwise>				
				</xsl:choose>			
			</xsl:otherwise>		
		</xsl:choose>	
	</xsl:template>	
	<xsl:template name="EllipseHyperlink" match="g" mode="EllipseHyperlink">		
		<xsl:param name="LookUpSAEntity"/>		
		<!-- the node in the assembly.xml file that contains the hyperlink-->		
		<xsl:param name="DefDDID"/>		
		<!-- the ddid of the item to be hyperlinked TO -->		
		<xsl:choose>			
			<xsl:when test="$LookUpSAEntity/@ChildReportName !='No Report'">				
				<xsl:variable name="ReportFile" select="$LookUpSAEntity/@ChildReportFile"/>				
				<xsl:variable name="ReportName" select="$LookUpSAEntity/@ChildReportName"/>				
				<xsl:variable name="AClnReportFile" select="translate($ReportFile,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz')"/>				
				<xsl:variable name="ClnReportFile" select="translate($AClnReportFile,'\/:*?&quot;&lt;&gt;| ','')"/>				
				<xsl:variable name="AClnReportName" select="translate($ReportName,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz')"/>				
				<xsl:variable name="ClnReportName" select="translate($AClnReportName,'\/:*?&quot;&lt;&gt;| ','')"/>				
				<xsl:choose>					
					<xsl:when test="($HomePageOptions/HomePageOptions/@HomePageUseReportPage='True') and (($DefDDID=$DefaultReport/SAItemToReport/@DDID) and ($ReportFile=$DefaultReport/@ReportFile) and ($ReportName=$DefaultReport/@ReportName))">						
						<xsl:element name="a">							
							<xsl:attribute name="xlink:href" >								
								<xsl:choose>									
									<xsl:when test="$HomePageOptions/@CreateBrowserTree='True'">										
										<xsl:text>Main.htm</xsl:text>									
									</xsl:when>									
									<xsl:otherwise>										
										<xsl:text>Default.htm</xsl:text>									
									</xsl:otherwise>								
								</xsl:choose>							
							</xsl:attribute>							
							<xsl:apply-templates mode="SimpleCopy" select="ellipse"/>						
						</xsl:element>					
					</xsl:when>					
					<xsl:otherwise>						
						<xsl:element name="a">							
							<xsl:attribute name="xlink:href" >								
								<xsl:text>getpage.aspx?ddid=</xsl:text>								
								<xsl:value-of select="$DefDDID"/>								
							</xsl:attribute>							
							<xsl:apply-templates mode="SimpleCopy" select="ellipse"/>						
						</xsl:element>					
					</xsl:otherwise>				
				</xsl:choose>			
			</xsl:when>			
			<xsl:otherwise>				
				<xsl:apply-templates mode="SimpleCopy" select="ellipse"/>			
			</xsl:otherwise>		
		</xsl:choose>	
	</xsl:template>	
	<xsl:template match="*|@*" mode="SimpleCopy">		
		<xsl:copy>			
			<xsl:apply-templates select="*|@*" mode="SimpleCopy"/>		
		</xsl:copy>	
	</xsl:template>
</xsl:stylesheet>